======================
sphinxcontrib-cadquery
======================

|docs-status|


A `Sphinx`_ extension for rendering `CadQuery`_ models.

**Development Status :: 2 - Pre-Alpha**

.. _Sphinx: https://www.sphinx-doc.org/
.. _CadQuery: https://cadquery.readthedocs.io/

.. |docs-status| image:: https://readthedocs.org/projects/sphinxcontrib-cadquery/badge/?version=latest
    :target: https://sphinxcontrib-cadquery.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation status
